Usage
S.independent(formula, family, data=NULL, trials=NULL, burnin, n.sample, thin=1,
prior.mean.beta=NULL, prior.var.beta=NULL, prior.sigma2=NULL, verbose=TRUE)
Arguments
formula
A formula for the covariate part of the model using the syntax of the
lm() function. Offsets can be included here using the offset() function. The
response can contain missing (NA) values.
family
One of either `binomial' or `poisson', which respectively specify a
binomial likelihood model with a logistic link function, or a Poisson likelihood
model with a log link function.
data
An optional data.frame containing the variables in the formula.
trials
A vector the same length as the response containing the total number of trials
for each area. Only used if family=`binomial'.
burnin
The number of McMC samples to discard as the burnin period.
n.sample
The number of McMC samples to generate.
thin
The level of thinning to apply to the McMC samples to reduce their temporal
autocorrelation. Defaults to 1.
prior.mean.beta
A vector of prior means for the regression parameters beta (Gaussian priors are
assumed). Defaults to a vector of zeros.
prior.var.beta
A vector of prior variances for the regression parameters beta (Gaussian priors
are assumed). Defaults to a vector with values 1000.
prior.sigma2
The prior shape and scale in the form of c(shape, scale) for an Inverse-Gamma(shape, scale)
prior for sigma2. Defaults to c(0.001, 0.001).
verbose
Logical, should the function update the user on its progress.