Usage
poisson.independent(formula, data = NULL, beta = NULL, theta = NULL, sigma2 = NULL,
burnin = 0, n.sample = 1000, thin=1, blocksize.beta = 5, blocksize.theta = 10,
prior.mean.beta = NULL, prior.var.beta = NULL, prior.max.sigma2 = NULL)
Arguments
formula
A formula for the covariate part of the model, using the same notation as for the lm() function. The offsets should also be included here using the offset() function.
data
A data.frame containing the variables in the formula.
beta
A vector of starting values for the regression parameters (including the intercept term). If this argument is not specified the function will randomly generate starting values.
theta
A vector of starting values for the random effects. If this argument is not specified the function will randomly generate starting values.
sigma2
A starting value for the variance parameter of the random effects. If this argument is not specified the function will randomly generate a starting value.
burnin
The number of MCMC samples to discard as the burnin period. Defaults to 0.
n.sample
The number of MCMC samples to generate. Defaults to 1,000.
thin
The level of thinning to apply to the MCMC samples to reduce their temporal autocorrelation. Defaults to 1.
blocksize.beta
The size of the blocks in which to update the regression parameters in the MCMC algorithm. Defaults to 5.
blocksize.theta
The size of the blocks in which to update the random effects in the MCMC algorithm. Defaults to 10.
prior.mean.beta
A vector of prior means for the regression parameters beta (Gaussian priors are assumed). Defaults to a vector of zeros.
prior.var.beta
A vector of prior variances for the regression parameters beta (Gaussian priors are assumed). Defaults to a vector with values 1000.
prior.max.sigma2
The maximum allowable value for the random effects variance sigma2 (a Uniform(0,M) prior is assumed). Defaults to M=1000.