Version 4.4 has two main changes from version 4.3. Firstly, the three functions S.CARiar(), S.independent() and S.CARleroux() have been merged into S.CARleroux(), as the latter is a generalisation of the other two. This has been achieved by adding two additional arguments to S.CARleroux, fix.rho (logical) and rho (numeric). The old model S.independent() can be obtained by setting (fix.rho=TRUE, rho=0), which corresponds to independent random effects. Similarly, the old model S.CARiar() corresponding to the intrinsic CAR model can be obtained by setting (fix.rho=TRUE, rho=1). The second change is that the modelfit component of the fitted model object now additionally returns the Watanabe-Akaike Information Criterion (WAIC) and an estimate of the effective number of effective parameters (p.w).
Lee, D. and Mitchell, R (2012). Boundary detection in disease mapping studies. Biostatistics, 13, 415-426.
Lee, D and Sarran, C (2015). Controlling for unmeasured confounding and spatial misalignment in long-term air pollution and health studies, Environmetrics, 26, 477-487.
Leroux, B., Lei, X and Breslow, N (1999). Estimation of disease rates in small areas: A new mixed model for spatial dependence, Chapter Statistical Models in Epidemiology, the Environment and Clinical Trials, Halloran, M and Berry, D (eds), pp. 135-178. Springer-Verlag, New York.
## See the examples in the function specific help files and in the vignette
## accompanying this package.Run the code above in your browser using DataLab